[java-identity-provider] branch maint-4 updated: IDP-2065 - Remediate UserAgentUtils library out of codebase

Scott Cantor cantor.2 at osu.edu
Wed Jan 11 15:47:37 UTC 2023


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch maint-4
in repository java-identity-provider.

View the commit online:
http://git.shibboleth.net/view/?p=java-identity-provider.git;a=commit;h=d7eef8c897af15b968d588e4004c135edbd83876

The following commit(s) were added to refs/heads/maint-4 by this push:
     new d7eef8c89 IDP-2065 - Remediate UserAgentUtils library out of codebase
d7eef8c89 is described below

commit d7eef8c897af15b968d588e4004c135edbd83876
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Wed Jan 11 10:47:34 2023 -0500

    IDP-2065 - Remediate UserAgentUtils library out of codebase
    
    https://shibboleth.atlassian.net/browse/IDP-2065
    
    Deprecate existing APIs.
---
 .../idp/authn/context/UserAgentContext.java           | 19 ++++++++++++++-----
 1 file changed, 14 insertions(+), 5 deletions(-)

diff --git a/idp-authn-api/src/main/java/net/shibboleth/idp/authn/context/UserAgentContext.java b/idp-authn-api/src/main/java/net/shibboleth/idp/authn/context/UserAgentContext.java
index 2b4f3bddb..95399632b 100644
--- a/idp-authn-api/src/main/java/net/shibboleth/idp/authn/context/UserAgentContext.java
+++ b/idp-authn-api/src/main/java/net/shibboleth/idp/authn/context/UserAgentContext.java
@@ -92,8 +92,11 @@ public final class UserAgentContext extends BaseContext {
     /**
      * Gets the parsed user agent.
      *
      * @return Parsed user agent or null if {@link #setIdentifier(String)} has not been called.
      */
+    @Deprecated(since="4.3.0", forRemoval=true)
     @Nullable public UserAgent getUserAgent() {
         return userAgent;
     }
@@ -101,10 +104,13 @@ public final class UserAgentContext extends BaseContext {
     /**
      * Determines whether this user agent is an instance of the given browser.
      *
-     * @param browser browser to check.
+     * @param browser browser to check
      *
      * @return True if this user agent is an instance of the given browser, false otherwise.
      */
+    @Deprecated(since="4.3.0", forRemoval=true)
     public boolean isInstance(@Nonnull final Browser browser) {
         Constraint.isNotNull(browser, "Browser cannot be null");
         if (userAgent == null) {
@@ -116,10 +122,13 @@ public final class UserAgentContext extends BaseContext {
     /**
      * Determines whether this user agent is an instance of the given operating system.
      *
-     * @param os operating system to check.
+     * @param os operating system to check
      *
      * @return True if this user agent is an instance of the given operating system, false otherwise.
      */
+    @Deprecated(since="4.3.0", forRemoval=true)
     public boolean isInstance(@Nonnull final OperatingSystem os) {
         Constraint.isNotNull(os, "OperatingSystem cannot be null");
         if (userAgent == null) {
@@ -92,8 +92,11 @@ public final class UserAgentContext extends BaseContext {
      * Gets the parsed user agent.
      *
-     * @return Parsed user agent or null if {@link #setIdentifier(String)} has not been called.
+     * @return Parsed user agent or null if {@link #setIdentifier(String)} has not been called
+     * 
+     * @deprecated
      */
@@ -101,10 +104,13 @@ public final class UserAgentContext extends BaseContext {
      *
-     * @return True if this user agent is an instance of the given browser, false otherwise.
+     * @return True if this user agent is an instance of the given browser, false otherwise
+     * 
+     * @deprecated
      */
@@ -116,10 +122,13 @@ public final class UserAgentContext extends BaseContext {
      *
-     * @return True if this user agent is an instance of the given operating system, false otherwise.
+     * @return True if this user agent is an instance of the given operating system, false otherwise
+     * 
+     * @deprecated
      */

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list